# CHANGELOG



## v0.1.0 (2023-12-07)

### Feature

* feat: use pdm publish ([`d937627`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/d937627c5a37ce6f04c33c155ac808455c0b348c))


## v0.0.2 (2023-12-07)

### Fix

* fix: rm todos ([`d648484`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/d648484bab07764a2a73960615980d9eea1139d2))


## v0.0.1 (2023-12-07)

### Chore

* chore: test sem release as action (#2)

* chore: test sem release as action

* chore: test sem release as action

* chore: GH_TOKEN

* fix: tests

* fix: github_token as input

* fix: add pdm dep

* fix: manually run semantic

* 0.0.1-rc.1

Automatically generated by python-semantic-release

* feat: use twine to upload package

* 0.1.0-rc.1

Automatically generated by python-semantic-release

* feat: use twine to upload package

* 0.1.0-rc.2

Automatically generated by python-semantic-release

* feat: use twine to upload package

* 0.1.0-rc.3

Automatically generated by python-semantic-release

* feat: fix twine env secrets

* 0.1.0-rc.4

Automatically generated by python-semantic-release

---------

Co-authored-by: Christoph Becker &lt;mail@ch-becker.de&gt;
Co-authored-by: Semantic commit &lt;a_bot_at@exb.de&gt; ([`d6c17d0`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/d6c17d06c5d8838bb373bbe8480086856bbeedfb))

* chore: update pdm ([`84d1a41`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/84d1a415284c568bcb2857e4799d4fb51d71ebb4))

* chore: add hash for sem release ([`5b0a65a`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/5b0a65a97c239243126b88a30194a8888946ff43))

### Fix

* fix: fix semver ([`0d14e1b`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/0d14e1b4afb4889ebdadc7293c5645995dbc983f))

### Refactor

* refactor: correct module name ([`4bbd1b8`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/4bbd1b8aa2fee0f292ca6a56553756ba0e4c28df))

### Unknown

* Actions packaging (#1)

* test: add simple

* chore: github workflow file

* chore: setup packaging incl actions

* chore: add test branch to actions

* refactor: rn test file

* chore: add semantic-release from branch

* chore: add semantic-release to action step

* chore: fix gh token

* chore: rm version source

* chore: rm version source

---------

Co-authored-by: Christoph Becker &lt;mail@ch-becker.de&gt; ([`2eea20b`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/2eea20b151ee2bda6809e0932c8595d349a84ea8))


## v0.0.0 (2023-12-06)

### Chore

* chore: gitignore ([`8d76a93`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/8d76a93c4531a982bf6a0a24cc4c5eedeb02581a))

### Feature

* feat: make info logging the default add debug option ([`11e7d38`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/11e7d3800cd4b2e0701ed62e0e05c2f8f7fccdbd))

### Fix

* fix: reading json, but there is text ([`5016c4f`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/5016c4f18f7b13deaa041b99ae2a80d89c8e39f0))

### Unknown

* README poiting to new home ([`34b5847`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/34b58478dc7e39f098f92e26e37cb37e5c8c75b8))

* doc: help added for env ([`2b87b84`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/2b87b8494fd9d6daef9900ced2192aa5894004cb))

* doc: updated ([`bf0b4fa`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/bf0b4fa7862d62e2c5901a8262d1d97f1505730c))

* more verbose logging ([`1e5cea3`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/1e5cea39a528fdd4c24c95e05a8053bf5f4e166f))

* Argparser added ([`79c948f`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/79c948f867a73a3a61e80d748a01347eb05e2826))

* finally create slack msg and send it ([`101622d`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/101622d05646f0d081b21039f7dde8eb9bb12a4e))

* Create structure with deployments and changes ([`609eb5f`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/609eb5fbb7ba3aa0b44b58186d8025fd8aa94bc8))

* Add multi-deployments support, return as stucture ([`256eda8`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/256eda82e211ecb4740bd67f291e1ac8956781dc))

* pdm lock ([`70bdef0`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/70bdef020b6f3c594ff715f4128406032eabc9dd))

* Add authors and script to pyproject ([`e1b7f71`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/e1b7f71a4bdbc4b2085261f975abd3f0095a0cde))

* Add slack sender ([`17ce48c`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/17ce48c2d694691d1f4281b693014eb0f66110ad))

* that&#39;s cool ([`4599a73`](https://github.com/ExB-Group/gitlab-deployment-changelog/commit/4599a73bf4bd5e61891be16a0492577c26c32c7c))
